'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
function _createCORSRequest(method, url) {
    var xhr = new XMLHttpRequest();
    if ('withCredentials' in xhr) {
        xhr.open(method, url, true);
    } else if (typeof XDomainRequest !== 'undefined') {
        xhr = new XDomainRequest();
        xhr.open(method, url);
    } else {
        xhr = null;
    }
    return xhr;
}

var RECEIVE_MONTE_CARLO = exports.RECEIVE_MONTE_CARLO = 'SM_WDGT.RECEIVE_MONTE_CARLO',
    SET_LOGGED_IN = exports.SET_LOGGED_IN = 'SM_WDGT.SET_LOGGED_IN',
    SET_ACCESS_TOKEN = exports.SET_ACCESS_TOKEN = 'SM_WDGT.SET_ACCESS_TOKEN',
    SET_ID_TOKEN = exports.SET_ID_TOKEN = 'SM_WDGT.SET_ID_TOKEN',
    SET_CLIENT_ID = exports.SET_CLIENT_ID = 'SM_WDGT.SET_CLIENT_ID',
    SET_SYSTEM_ID = exports.SET_SYSTEM_ID = 'SM_WDGT.SET_SYSTEM_ID',
    SET_APP_ID = exports.SET_APP_ID = 'SM_WDGT.SET_APP_ID',
    SET_EMPTY_FP = exports.SET_EMPTY_FP = 'SM_WDGT.SET_EMPTY_FP',
    SET_MISSING_CLIENT = exports.SET_MISSING_CLIENT = 'SM_WDGT.SET_MISSING_CLIENT',
    MONTE_CARLO = exports.MONTE_CARLO = function MONTE_CARLO(appId, systemId, clientId) {
    return !window.ADVIZR.internal_testing ? {
        url: window.ADVIZR.webapi_endpoint + 'monte-carlo/?systemId=' + systemId + '&extClientId=' + clientId,
        handler: receive_monte_carlo
    } : { url: window.ADVIZR.webapi_endpoint + 'monte-carlo/?clientId=' + clientId, handler: receive_monte_carlo };
};

var receive_monte_carlo = exports.receive_monte_carlo = function receive_monte_carlo(monte_carlo) {
    return {
        type: RECEIVE_MONTE_CARLO,
        monte_carlo: monte_carlo
    };
};

var set_access_token = exports.set_access_token = function set_access_token(access_token) {
    return {
        type: SET_ACCESS_TOKEN,
        access_token: access_token
    };
};

var set_id_token = exports.set_id_token = function set_id_token(id_token) {
    return {
        type: SET_ID_TOKEN,
        id_token: id_token
    };
};

var set_logged_in = exports.set_logged_in = function set_logged_in(logged_in) {
    return {
        type: SET_LOGGED_IN,
        logged_in: logged_in
    };
};

var set_empty_fp = exports.set_empty_fp = function set_empty_fp(fp_empty) {
    return {
        type: SET_EMPTY_FP,
        fp_empty: fp_empty
    };
};

var set_client_id = exports.set_client_id = function set_client_id(clientId) {
    return {
        type: SET_CLIENT_ID,
        clientId: clientId
    };
};

var set_system_id = exports.set_system_id = function set_system_id(systemId) {
    return {
        type: SET_SYSTEM_ID,
        systemId: systemId
    };
};

var set_app_id = exports.set_app_id = function set_app_id(appId) {
    return {
        type: SET_APP_ID,
        appId: appId
    };
};

var set_missing_client = exports.set_missing_client = function set_missing_client(client_missing) {
    return {
        type: SET_MISSING_CLIENT,
        client_missing: client_missing
    };
};

var fetch_data = exports.fetch_data = function fetch_data(type, access_token) {
    return function (dispatch) {
        dispatch(set_access_token(access_token));
        var url = '' + type.url,
            xhr = _createCORSRequest('GET', url);
        xhr.setRequestHeader('Authorization', 'Bearer ' + access_token);
        xhr.onload = function () {
            var resp = xhr.response;
            switch (xhr.status || xhr.statusCode) {
                case 401:
                    dispatch(set_logged_in(false));
                    break;
                case 400:
                    dispatch(set_missing_client(true));
                    break;
                case 204:
                    dispatch(set_empty_fp(true));
                    break;
                case 200:
                    dispatch(set_empty_fp(false));
                    dispatch(set_missing_client(false));
                    dispatch(type.handler.call(null, resp));
                    break;
            }
        };
        xhr.send();
    };
};

var check_logged_in = exports.check_logged_in = function check_logged_in() {
    return function (dispatch) {
        window.ADVIZR.um.getUser().then(function (user) {
            if (!user) {
                set_logged_in(false);
            } else {
                var logged_in = !!window.ADVIZR.um && !user.isExpired,
                    _window$ADVIZR$store$ = window.ADVIZR.store.getState().MonteCarloWidget,
                    systemId = _window$ADVIZR$store$.systemId,
                    appId = _window$ADVIZR$store$.appId,
                    clientId = _window$ADVIZR$store$.clientId;

                console.log(window.ADVIZR.um.getUser());
                dispatch(set_logged_in(logged_in));

                if (logged_in) {
                    dispatch(set_id_token(user.id_token));
                    dispatch(fetch_data(MONTE_CARLO(appId, systemId, clientId), user.access_token));
                }
            }
        });
    };
};

var setIdAndAccessTokens = exports.setIdAndAccessTokens = function setIdAndAccessTokens(id_token, access_token) {
    return function (dispatch) {
        var _window$ADVIZR$store$2 = window.ADVIZR.store.getState().MonteCarloWidget,
            systemId = _window$ADVIZR$store$2.systemId,
            appId = _window$ADVIZR$store$2.appId,
            clientId = _window$ADVIZR$store$2.clientId;

        dispatch(set_logged_in(true));
        dispatch(set_id_token(id_token));
        dispatch(fetch_data(MONTE_CARLO(appId, systemId, clientId), access_token));
    };
};

window.ADVIZR = Object.assign({}, window.ADVIZR, { setIdAndAccessTokens: setIdAndAccessTokens });
window.ADVIZR = Object.assign({}, window.ADVIZR, { set_client_id: set_client_id });