'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});
exports.get_monte_carlo_chart_data = exports.get_monte_carlo_probability_data = undefined;

var _reselect = require('reselect');

var _chartDescriptors = require('../chart/chartDescriptors.overview');

var _extensions = require('../helpers/extensions');

var get_monte_carlo_probability_data = exports.get_monte_carlo_probability_data = (0, _reselect.createSelector)([function (state) {
    return state.MonteCarloWidget ? state.MonteCarloWidget.monte_carlo : undefined;
}, function (state) {
    return state.MonteCarloWidget ? state.MonteCarloWidget.target_low : undefined;
}], function (chart, target_low) {
    if (typeof chart === 'undefined' || Object.keys(chart).length < 1) return;

    var chart_data = (0, _extensions.clone)(_chartDescriptors.MonteCarloProbability),
        pos = chart.probabilityOfSuccess * 100,
        inverse_pos = 100 - pos;

    chart_data.series[0].data = [{
        name: 'Unsuccessful',
        y: inverse_pos,
        color: '#444444'
    }, {
        name: 'Successful',
        y: pos,
        color: pos < target_low ? '#e75953' : '#89ce41'
    }];

    return chart_data;
});

var get_monte_carlo_chart_data = exports.get_monte_carlo_chart_data = (0, _reselect.createSelector)([function (state) {
    return state.MonteCarloWidget ? state.MonteCarloWidget.monte_carlo : undefined;
}], function (chart) {
    if (typeof chart === 'undefined' || Object.keys(chart).length < 1) return;

    var chart_data = (0, _extensions.clone)(_chartDescriptors.MonteCarlo),
        pos = chart.probabilityOfSuccess * 100,
        inverse_pos = 100 - pos,
        pos_color = chart.successfulColor,
        inverse_pos_color = chart.unsuccessfulColor;

    chart_data.series = chart.data;
    chart_data.xAxis.categories = chart.categories;

    if (chart.isEmpty) {
        chart_data.yAxis.max = 10000;
    }

    chart_data.tooltip.formatter = function () {
        return '<div class="MonteCarloChartTooltip">\n                <h2>Probability of Success</h2>\n                We ran ' + chart.monteCarloTrialsCount + ' trials to simulate a range of possible outcomes.\n                <ul class="outcomes">\n                    <li>\n                        <i style="background-color:' + pos_color + ';"></i><b>' + pos + '%</b> of the time you were fully funded for your retirement.\n                    </li>\n                    <li>\n                        <i style="background-color:' + inverse_pos_color + ';"></i><b>' + inverse_pos + '%</b> of the time you ran out of money.\n                    </li>\n                </ul>\n            </div>';
    };

    return chart_data;
});